@@ -706,15 +706,17 @@ bool Keys::delKey(const char *key) {
 }
 
 
-/*! Read configulation file into a key.
+/*! Read structured text file into a Keys.
     @param filename  File name to read.
     @retval true  success
     @retval false failure
  */
-bool Keys::loadConfigFile(const char *filename) {
+bool Keys::loadFile(const char *filename) {
   String str, line, key, value, tmp_str;
   long len, i, j, k;
 
+  (*this).clear();
+
   len = str.loadFile(filename);
   if (len < 0L) {
     return false;
@@ -731,12 +733,12 @@ bool Keys::loadConfigFile(const char *filename) {
       if (0L < line.len() && line[0] != '#' && 0 < (k = line.searchChar('='))) {
         String p, p1;
         p = line;
-        p1 = p.left(k).trimR();
+        p1 = p.left(k).trim();
         key = p1;
-        p1 = p.mid(k+1).trimL();
+        p1 = p.mid(k+1).trim();
         value = p1;
         if (2L <= value.len() && value[0] == '"' && value[value.len()-1] == '"') {
-          tmp_str = value.mid(1, value.len()-1);
+          tmp_str = value.mid(1, value.len()-2);
           value = tmp_str.unescapeQuote();
           tmp_str.clear();
         }
@@ -752,4 +754,40 @@ bool Keys::loadConfigFile(const char *filename) {
   return true;
 }
 
+/*! Write structured text file of serialized Keys.
+    @param filename  File name to wtite.
+    @retval true  success
+    @retval false failure
+ */
+bool Keys::saveFile(const char *filename) const {
+  long m, i;
+  String str, tmp_str1, tmp_str2;
+  bool ret;
+
+  m = (*this).max();
+  str.sprintf("# %ld key(s)\n", m);
+  for (i = 0; i < m; i++) {
+    str += (*this).key(i);
+    tmp_str1 = (*this).value(i).trim();
+    tmp_str2 = (*this).value(i).escapeQuote();
+    if (tmp_str1 == tmp_str2) {
+      str += "=";
+      str += tmp_str1;
+      str += "\n";
+    } else {
+      str += "=\"";
+      str += tmp_str2;
+      str += "\"\n";
+    }
+  }
+
+  ret = str.saveFile(filename);
+
+  tmp_str1.clear();
+  tmp_str2.clear();
+  str.clear();
+
+  return ret;
+}
+
 } // namespace apolloron
