@@ -14,7 +14,7 @@ namespace apolloron_html_client {
 
 /*! @brief Version of libapolloron_html_client.
  */
-#define LIBAPOLLORON_HTML_CLIENT_VERSION "0.01.0"
+#define LIBAPOLLORON_HTML_CLIENT_VERSION "0.02.0"
 
 
 /*----------------------------------------------------------------------------*/
@@ -34,7 +34,7 @@ public:
   virtual bool clear();
 
   // get content specified by URL
-  virtual apolloron::String& getURL(const apolloron::String &url);
+  virtual apolloron::String& getURL(const apolloron::String &url, long timeout=5);
 
   // get content original charset 
   virtual apolloron::String& getOrigCharset();
